#ifndef __COMMANDS_H__
#define __COMMANDS_H__
/************************************************************************/
/* 
 * Header:	commands.h
 * Purpose:     to define commandd functions
 * Language/Compiler/O/S:   GCC 2.7.2
 * Author:      Wade Hampton
 * Date:        12/23/97
 * Revision History:
 * [from RCS]
 *
 * $Log: commands.h,v $
 * Revision 1.1  1997/12/24 15:43:46  wadeh
 * Initial revision
 *
 *
 * Notes:
 * 1) 
 *----------------------------------------------------------------------*/
/* TYPES- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/* INCLUDE FILES- - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/* CONSTANTS- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/* LOCAL DATA - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/* EXTERNAL PROCEDURES- - - - - - - - - - - - - - - - - - - - - - - - - */
/* EXTERNAL DATA- - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/* PROTOTYPES - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
void do_play(char *progname, int cdfile, int trk0, int trk1, int iVerbose);
void do_pause(char *progname, int cdfile, int iVerbose);
void do_stop(char *progname, int cdfile, int iCDNum, int iVerbose);
void do_eject(char *progname, int cdfile, int iVerbose);
void do_reset(char *progname, int cdfile, int iVerbose);
/*
 * Copyright (C) 1997, 1998 Wade Hampton
 */
/************************************************************************/
#endif


